@@ -371,7 +371,7 @@ class Unet3D(nn.Module):
 
         # initial conv
 
-        init_dim = default(init_dim, dim // 3 * 2)
+        init_dim = default(init_dim, dim)
         assert is_odd(init_kernel_size)
 
         init_padding = init_kernel_size // 2
@@ -438,7 +438,7 @@ class Unet3D(nn.Module):
 
         self.mid_block2 = block_klass_cond(mid_dim, mid_dim)
 
-        for ind, (dim_in, dim_out) in enumerate(reversed(in_out[1:])):
+        for ind, (dim_in, dim_out) in enumerate(reversed(in_out)):
             is_last = ind >= (num_resolutions - 1)
 
             self.ups.append(nn.ModuleList([
@@ -451,7 +451,7 @@ class Unet3D(nn.Module):
 
         out_dim = default(out_dim, channels)
         self.final_conv = nn.Sequential(
-            block_klass(dim * 2, dim),
+            block_klass(dim, dim),
             nn.Conv3d(dim, out_dim, 1)
         )
 
@@ -520,7 +520,6 @@ class Unet3D(nn.Module):
             x = temporal_attn(x, pos_bias = time_rel_pos_bias, focus_present_mask = focus_present_mask)
             x = upsample(x)
 
-        x = torch.cat((x, h.pop()), dim = 1)
         return self.final_conv(x)
 
 # gaussian diffusion trainer class
